@@ -10,7 +10,7 @@ cat catalog/dfiles/files |
 sed -e 's@^[^/]*/@@' |
 grep -v -e '^catalog/' -e '^$' |
 cat |
-tar cf - --files-from=- --no-recursion |
+tar cf - --no-recursion --files-from=- |
 (cd $distdir && tar xpf -)
 
 
