@@ -6,7 +6,7 @@ case "$1" in
 	*)
 		;;
 esac
-
+touch compile
 version="$1"
 set -vx
 cat configure.ac |
@@ -15,6 +15,10 @@ cat > configure.ac.new
 diff configure.ac configure.ac.new
 cat < configure.ac.new >configure.ac
 rm configure.ac.new
+rm aclocal.m4
+aclocal
+automake
 echo "$version" >VERSION
-autoconf && automake
+aclocal && autoconf && automake --add-missing
+rm compile
 exit $?
