@@ -204,5 +204,8 @@ void swc_check_all_pax_commands(GB * G);
 void swc_check_shell_command_key(GB * G, char * cmd);
 char * swc_get_default_sh_dash_s(GB * G);
 STROB * swc_make_multiplepathlist(STRAR * sourcepath_listM, STROB * rootdir, STROB * firstpath);
+int swc_read_target_message_129(GB * G, int fd, STROB * cdir, int vlevel, char * loc);
+char * swc_make_absolute_path(char * target_current_dir, char * target_path);
+
 
 #endif
