@@ -97,7 +97,7 @@ swc0_process_w_option(STROB * tmp, CPLOB * w_arglist,
 
 int
 swc0_set_arf_format(char * user_optarg, int * format_arf, int * do_oldgnutar, 
-	int * do_bsdpax3, int * do_oldgnuposix, int * do_gnutar)
+	int * do_bsdpax3, int * do_oldgnuposix, int * do_gnutar, int * do_paxexthdr)
 {
 	if (user_optarg == (char*)NULL) return 0;
 
@@ -105,6 +105,11 @@ swc0_set_arf_format(char * user_optarg, int * format_arf, int * do_oldgnutar,
   		*format_arf = arf_ustar;
 		*do_gnutar = 0;
 		*do_oldgnuposix = 0;
+	} else if (!strcasecmp(user_optarg,"posix")  || !strcasecmp(user_optarg, "pax")) {
+  		*format_arf = arf_ustar;
+		*do_paxexthdr = 1;
+		*do_gnutar = 0;
+		*do_oldgnuposix = 0;
 	} else if (!strcmp(user_optarg,"newc")) {
 		*format_arf = arf_newascii;
 	} else if (
