@@ -117,6 +117,7 @@ volatile int global_lastsig;
 #define SWBIS_TS_Load_management_host_status "Load manangement host status"
 #define SWBIS_TS_check_OVERWRITE	"Check overwrites"
 #define SWBIS_TS_check_status		"Check Status"
+#define SWBIS_TS_Get_prelink_filelist	"Get prelink file list"   /* swverify */
 
 
 
@@ -161,7 +162,7 @@ void swc_setErrorCode(ERRORCODE * EC, int code, char *);
 int swc_getErrorCode(ERRORCODE * EC);
 
 int swc0_set_arf_format(char * optarg, int * format_arf, int * do_oldgnutar,
-	int * do_bsdpax3, int * do_oldgnuposix, int * do_gnutar);
+	int * do_bsdpax3, int * do_oldgnuposix, int * do_gnutar, int * do_paxexthdr);
   
 int swc0_process_w_option(STROB * tmp, CPLOB * w_arglist, char * i_optarg,
 	int * w_argc_p);
