@@ -194,7 +194,7 @@ fprintf(fp, "%s",
 " Swbis Extended Options:\n"
 "        File : <libdir>/swbis/swbisdefaults\n"
 "               ~/.swbis/swbisdefaults\n"
-"        Command Line Syntax : -x option=option_argument\n"
+"        Command Line Syntax : -W option=option_argument\n"
 "  swconfig.swbis_no_getconf		 = true # getconf is used\n"
 "  swconfig.swbis_shell_command	         = detect\n"
 "  swconfig.swbis_no_remote_kill	 = false\n"
@@ -513,6 +513,8 @@ main(int argc, char **argv)
 	int * p_do_progressmeter;
 	int make_master_raw = 1;
 	int is_local_stdin_seekable = 0;
+	int tmpret;
+	int tmp_status;
 	int nullfd;
 	int testnum = 0;
 	int f_retval = 0;	/* protocol, internal errors */
@@ -915,11 +917,15 @@ main(int argc, char **argv)
 	while (1) {
 		int option_index = 0;
 
-		c = ugetopt_long(argc, argv, "uf:t:pvs:X:x:W:", 
+		c = ugetopt_long(argc, argv, "Auf:t:pvs:X:x:W:", 
 					main_long_options, &option_index);
 		if (c == -1) break;
 
 		switch (c) {
+		case 'A':
+			wopt_forward_agent = CHARTRUE;
+			set_opta(opta, SW_E_swbis_forward_agent, wopt_forward_agent);
+			break;
 		case 'u':
 			G->g_do_unconfigM = 1;
 			break;
@@ -1921,11 +1927,37 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 						"source");
 
 			if (ret < 0) {
+				/*
+				 * This is (may be) the failure path for ssh authentication
+				 * failure.
+				 */
+		
+				/*
+				 * See if the ssh command has finished.
+				 */
+				if (swlib_wait_on_pid_with_timeout(ss_pid, &tmp_status, 0 /*flags*/, 1/*verbose_level*/, 3 /* Seconds */) > 0) {
+					/*
+					 * Store the result in the status array.
+					 */
+					SWLIB_ASSERT(
+						swlib_update_pid_status(ss_pid, tmp_status,
+							G->g_pid_array, G->g_status_array, G->g_pid_array_len) == 0);
+				}
+				E_DEBUG("ABCD");
+				if (WIFEXITED(tmp_status)) {
+					/*
+					 * This is the exit status of ssh (or rsh)
+					 */
+					tmpret = WEXITSTATUS(tmp_status);
+					swpl_agent_fail_message(G, current_arg, tmpret);
+				} else {
+					sw_e_msg(G, "SW_INTERNAL_ERROR for target %s in file %s at line %d\n",
+						current_arg, __FILE__, __LINE__);
+				}
+
 				/* Error, start message indicated failure */
 				LC_RAISE(SIGTERM);
-				/* Signal Check */
 				swc_check_for_current_signals(G, __LINE__, wopt_no_remote_kill);
-				sw_e_msg(G, "read_start_ctl_message error (loc=start)\n");
 				LCEXIT(sw_exitval(G, target_loop_count, target_success_count));
 			}
 
