@@ -667,7 +667,6 @@ compare_names(char * mname, char * sname)
 	return strncmp(mname_start, sname_start, ml);
 }
 
-
 static
 char * 
 return_normal_name (STROB * buf, INFOLINE * info_inl)
@@ -733,6 +732,7 @@ determine_inl_field_condition(INFOLINE * status_inl, INFOLINE * info_inl, INFOLI
 		ti->lenM == ts->lenM &&
 		strncmp(ti->addrM, ts->addrM, ti->lenM) == 0
 	) {
+		E_DEBUG("present and equal");
 		ret = INL_STATUS_1_1_EQ;
 		set_rpmv_field_condition(status_inl, rpmv_offset, RPMV_fail_NOT);
 		if (offset == INL_OWNERS_OFFSET ) {
@@ -745,6 +745,7 @@ determine_inl_field_condition(INFOLINE * status_inl, INFOLINE * info_inl, INFOLI
 		ts->lenM > 0 &&
 		strncmp(ti->addrM, ts->addrM, ti->lenM)
 	) {
+		E_DEBUG("present and unequal");
 		if (offset == INL_OWNERS_OFFSET ) {
 			/* FIXME consider owner and group separately */
 			set_rpmv_field_condition(status_inl, RPMV_offset_user, RPMV_fail_fail);
@@ -757,18 +758,21 @@ determine_inl_field_condition(INFOLINE * status_inl, INFOLINE * info_inl, INFOLI
 		ti->lenM == 0 &&
 		ts->lenM == 0
 	) {
+		E_DEBUG("lenM is 0 for both");
 		set_rpmv_field_condition(status_inl, rpmv_offset, RPMV_fail_NOT/*FIXME is this right? */);
 		ret = INL_STATUS_0_0_NA;
 	} else if ( 
 		/* present in INFO only */
 		ti->lenM > 0
 	) {
+		E_DEBUG(" in INFO only");
 		set_rpmv_field_condition(status_inl, rpmv_offset, RPMV_fail_fail);
 		ret = INL_STATUS_1_0_NA;	
 	} else if ( 
 		/* present in SYSTEM only */
 		ts->lenM > 0
 	) {
+		E_DEBUG(" in SYSTEM only");
 		set_rpmv_field_condition(status_inl, rpmv_offset, RPMV_fail_unknown);
 		ret = INL_STATUS_0_1_NA;
 	} else {
@@ -785,14 +789,28 @@ determine_inl_field_condition(INFOLINE * status_inl, INFOLINE * info_inl, INFOLI
 	return ret;
 }
 
+
+static
+void
+set_inl_field_status_conditionally(INFOLINE * status_inl, int offset, int status)
+{
+	INFOITEM * t = (INFOITEM*)(((char*)status_inl)+offset);
+	int current_status;
+	current_status = t->statusM;
+	if (current_status == INL_STATUS_1_1_EQ && status != INL_STATUS_1_1_EQ)
+		t->statusM = status;
+	return;
+}
+
 static
 int
 get_inl_field_status(INFOLINE * status_inl, int offset)
 {
 	int current_status;
 	INFOITEM * t = (INFOITEM*)(((char*)status_inl)+offset);
-	E_DEBUG("");
 	current_status = t->statusM;
+	E_DEBUG2("READING STATUS at [%p]", (void*)&(t->statusM));
+	E_DEBUG3("OFFSET(ATTR)=[%d] current_status=[%d]", offset, current_status);
 	return current_status;
 }
 
@@ -1226,6 +1244,7 @@ write_summary_report(GB * G, INFOLINE * status_inl, STROB * rpt)
 	retval = 0;	
 
 	ret = get_inl_field_status(status_inl, INL_NAME_OFFSET);
+	E_DEBUG2("FILE LIST ret=[%d]", ret);
 	strob_sprintf(rpt, 1, "%s: INFO check: %30s: %s\n", swlib_utilname_get(),
 	"Fileset file list",
 	inl_status_msg(ret));
@@ -1355,7 +1374,8 @@ compare_diff(GB * G, SWI * swi, int ofd, int ifd, STROB * rpt_diff, STROB * rpt_
 	s_s = strar_get(sys, is);
 	status_inl->nameM.statusM = INL_STATUS_1_1_EQ;
 	while (m_s) {
-		status_inl->nameM.statusM = INL_STATUS_1_1_EQ;
+		/* status_inl->nameM.statusM = INL_STATUS_1_1_EQ; */
+		set_inl_field_status_conditionally(status_inl, INL_NAME_OFFSET, INL_STATUS_1_1_EQ);
 		E_DEBUG2("NAME m_s=%s", m_s);
 		if (G->g_ignore_slack_installM) {
 			name = inl_get_name(m_s, &name_len);		
@@ -1379,7 +1399,7 @@ compare_diff(GB * G, SWI * swi, int ofd, int ifd, STROB * rpt_diff, STROB * rpt_
 			/* good, lines match */
 			im++;
 			is++;
-			E_DEBUG("match");
+			E_DEBUG("000000000000000000000000000 match");
 			if (do_show) {
 				if (
 					G->g_output_formM == SWVERIFY_OUTF_DIFF ||
@@ -1400,7 +1420,7 @@ compare_diff(GB * G, SWI * swi, int ofd, int ifd, STROB * rpt_diff, STROB * rpt_
 		} else if (m_s && s_s && strcmp(m_s, s_s) != 0) {
 			/* either changed or deleted file */
 			retval++;
-			E_DEBUG("mis match");
+			E_DEBUG("000000000000000000000 mis match");
 			if (compare_names(m_s, s_s) == 0) {
 				/* changed file */
 				compare_ret = inl_compare_infoline(tmpbuf, G, swi, ofd, ifd,
@@ -1429,8 +1449,10 @@ compare_diff(GB * G, SWI * swi, int ofd, int ifd, STROB * rpt_diff, STROB * rpt_
 				write_rpmv_output_line(G, status_inl, m_s_inl, target_path);
 			} else {
 				/* missing file */
-				E_DEBUG("missing file");
-				status_inl->nameM.statusM = INL_STATUS_MISSING_FILE;
+				E_DEBUG("000000000000000 missing file");
+				/* status_inl->nameM.statusM = INL_STATUS_MISSING_FILE; */
+				set_inl_field_status_conditionally(status_inl, INL_NAME_OFFSET, INL_STATUS_MISSING_FILE);
+				E_DEBUG2("MISSING FILE: &statusM=[%p]", (void*)&(status_inl->nameM.statusM));
 				if (
 					G->g_output_formM == SWVERIFY_OUTF_DIFF ||
 					G->g_output_formM == SWVERIFY_OUTF_ALL
@@ -1446,8 +1468,10 @@ compare_diff(GB * G, SWI * swi, int ofd, int ifd, STROB * rpt_diff, STROB * rpt_
 			E_DEBUG("diff");
 		} else if (m_s && !s_s) {
 			/* files missing at end */
+			E_DEBUG("000000000000000 missing file at end");
 			retval++;
-			status_inl->nameM.statusM = INL_STATUS_MISSING_FILE;
+			/* status_inl->nameM.statusM = INL_STATUS_MISSING_FILE; */
+			set_inl_field_status_conditionally(status_inl, INL_NAME_OFFSET, INL_STATUS_MISSING_FILE);
 				if (
 					G->g_output_formM == SWVERIFY_OUTF_DIFF ||
 					G->g_output_formM == SWVERIFY_OUTF_ALL
