@@ -6,6 +6,14 @@
 //  This file may be copied under the terms of the GNU GPL.
 //
 
+extern "C" {
+#include "swuser_config.h"
+}
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <limits.h>
 #include <tar.h>
 #include <sys/types.h>
 #include <fcntl.h>
