@@ -308,9 +308,9 @@ class swExFileset: public swObjFiles_i
 		// <path>/catalog/ 
 		//
 		
-		s = strstr(strob_str(tmp), SW_CATALOG);
+		s = strstr(strob_str(tmp), SW_A_catalog);
 		SWLIB_ASSERT(s != NULL);
-		s += strlen(SW_CATALOG);
+		s += strlen(SW_A_catalog);
 		
 		if ( (*s == '/' && *(s+1) == '\0') || (*(s+0) == '\0')) {
 			//
@@ -472,10 +472,10 @@ class swExFileset: public swObjFiles_i
 
 				file_hdr = taru_make_header();
 				xp = swdef->find(SW_A_major);
-				file_hdr->c_rdev_maj = swlib_atoul(xp, &xresult);
+				file_hdr->c_rdev_maj = swlib_atoul(xp, &xresult, (char**)NULL);
 				if (xresult) setErrorCode(12306, NULL);
 				xp = swdef->find(SW_A_minor);
-				file_hdr->c_rdev_min = swlib_atoul(xp, &xresult);
+				file_hdr->c_rdev_min = swlib_atoul(xp, &xresult, (char**)NULL);
 				if (xresult) setErrorCode(12307, NULL);
 				assertNoErrorCondition(41);
 				xret = taru_check_devno_for_tar(file_hdr);
@@ -569,6 +569,7 @@ class swExFileset: public swObjFiles_i
 					}
 				}
 				SWEXFILESET_DEBUG2("<<<<< writing [%s]", tmp->str_);
+
 				/* Final sanity check on the archive path */
 				if (strstr(strob_str(tmp), "../")) {
 					retval = -1;
@@ -577,8 +578,14 @@ class swExFileset: public swObjFiles_i
 				}
 			} 
 			skip = 0;	
-			
-			if (retval < 0) {
+		
+			//
+			// If retval =  TARU_HE_LINKNAME_4 i.e. -4 then just leave it out of the
+			// storage section.
+			//
+
+	
+			if (retval < 0 && retval != TARU_HE_LINKNAME_4 /* link name too long */) {
 				fprintf(stderr,
 					"%s: error writing archive member, status=%s, name=%s\n",
 					swlib_utilname_get(), swlib_imaxtostr(retval, NULL), strob_str(tmp));
