@@ -128,7 +128,7 @@ class swExProduct: public swExCat
 				char * catalog_string;
 
 				if (code == emitExportedCatalogE) {
-					catalog_string = SW_CATALOG;
+					catalog_string = SW_A_catalog;
 				} else {
 					catalog_string = NULL;
 				}
@@ -138,9 +138,9 @@ class swExProduct: public swExCat
 				strob_strcpy(tmp, getFormedControlPath(static_cast<char*>(NULL), static_cast<char*>(catalog_string)));
 
 				if (code == emitExportedCatalogE) {
-                			s = strstr(strob_str(tmp), SW_CATALOG);
+                			s = strstr(strob_str(tmp), SW_A_catalog);
                 			SWLIB_ASSERT(s != NULL);
-                			s += strlen(SW_CATALOG);
+                			s += strlen(SW_A_catalog);
                 			if ( (*s == '/' && *(s+1) == '\0') || *(s) == '\0') {
 							//
 							// Don't write it.
