@@ -1014,7 +1014,7 @@ class swObjFiles_i:  public swExStruct_i
 					SWLIB_ASSERT(source != NULL);
 	
 					ret = processCatalogFile(swattfile,
-								source,
+								strdup(source),
 								swdef, 1);
 					if (ret) {
 						fprintf(stderr,
@@ -1088,7 +1088,9 @@ class swObjFiles_i:  public swExStruct_i
 				if (*value == ':') {
 					//
 					// Dup'ing this fixed a core dump
-					// 
+					// Because the memory ''value'' points to 
+					// is subject to reallocation on a size increase.
+					//
 					value2 = strdup(value);
 					value = value2;
 				} else {
@@ -1121,7 +1123,7 @@ class swObjFiles_i:  public swExStruct_i
 				swdef->add(SWBIS_CATALOG_GROUP_ATT,
 							getCatalogGroup(), 1);
 				
-				ret = processCatalogFile(swattfile, value,
+				ret = processCatalogFile(swattfile, strdup(value),
 						swdef, 0/* logical off*/);
 				if (ret) {
 					fprintf(stderr,
@@ -1352,7 +1354,7 @@ class swObjFiles_i:  public swExStruct_i
 		// emitLeadingDirectory().
 		//
 		strob_strcpy(tmp, getFormedControlPath(static_cast<char*>(NULL), 
-					(char*)(SW_CATALOG)));
+					(char*)(SW_A_catalog)));
 
 		emitLeadingCatalogDirectory(tmp);
 		
@@ -1401,7 +1403,7 @@ class swObjFiles_i:  public swExStruct_i
 			strob_strcpy(tmp,
 				getFormedControlPath(
 					static_cast<char*>(NULL),
-					(char*)(SW_CATALOG))
+					(char*)(SW_A_catalog))
 				);
 			swlib_unix_dircat(tmp,
 				swfile->swfile_get_package_filename());
@@ -1719,7 +1721,7 @@ class swObjFiles_i:  public swExStruct_i
 		strob_strcpy(tmp,
 			getFormedControlPath(
 				static_cast<char*>(NULL),
-				(char*)(SW_CATALOG))
+				(char*)(SW_A_catalog))
 		);
 
 		swlib_unix_dircat(tmp, 
@@ -1841,7 +1843,6 @@ class swObjFiles_i:  public swExStruct_i
 				strob_close(tmp);
 				return -2;
 			}
-			psource++;  // Skip over the colon
 
 			//
 			// This routine adds a '\n' to the data stream
@@ -1851,7 +1852,8 @@ class swObjFiles_i:  public swExStruct_i
 			// FIXME: swdef_write_value() doesn't need to be
 			// used here???
 			//
-			swdef_write_value(psource, datafd,
+			// Skip over the colon on psource
+			swdef_write_value((char*)psource + 1, datafd,
 					0 /*special meaning*/,
 					1 /*quote off*/);
 
@@ -1888,6 +1890,7 @@ class swObjFiles_i:  public swExStruct_i
 		
 		swvarfs_set_stat_syscall(getSwvarfs(), old_stat);
 		strob_close(tmp);
+		free(psource);
 		return 0;
 	}
 
