@@ -58,10 +58,12 @@ cplob_open(int nobj)
 	}
 	null_list(lob, 0, nobj);
 	lob->width = sizeof(char*);
+	lob->refcountM = 0;
 	cplob_shallow_reset(lob);
 	return lob;
 }
 
+
 o__inline__
 char ** 
 cplob_release(CPLOB * lob)
@@ -138,10 +140,13 @@ cplob_add_nta(CPLOB * lob, char *addr)
 	/* add to end of null terminated array */
 	if (!lob->nused){
 		lob->nused++;
+		cplob_reopen(lob->nused + CPLOB_NLENGTHINCR, lob);
 		*(lob->list + (lob->nused-1)) = addr;
 		if (!addr){
 			return;						
 		}
+	} else {
+		cplob_reopen(lob->nused + CPLOB_NLENGTHINCR, lob);
 	}
 	*(lob->list + (lob->nused-1)) = addr;
 	cplob_additem(lob, lob->nused, NULL);
