@@ -1,6 +1,6 @@
 /* topsf.c  --  Open (almost) any format and translate to a PSF and archive.
 
-   Copyright (C) 1999,2007  Jim Lowe 
+   Copyright (C) 1999,2007,2014  Jim Lowe 
    All rights reserved.
 
    COPYING TERMS AND CONDITIONS:
@@ -683,9 +683,9 @@ TOPSF * topsf_open(char * filename, int oflags, char * package_name)
 	
 	if (strcmp(filename, "-") == 0 && package_name != NULL) {
 		/* fprintf(stderr, "JL you're a SLACKER: %s:%s at line %d\n", __FILE__, __FUNCTION__, __LINE__); */
-		topsf->fd_ = uinfile_open_with_name(filename, (mode_t)(NULL), &(topsf->format_desc_), oflags, package_name); 
+		topsf->fd_ = uinfile_open_with_name(filename, (mode_t)(0), &(topsf->format_desc_), oflags, package_name); 
 	} else {
-		topsf->fd_ = uinfile_open(filename, (mode_t)(NULL), &(topsf->format_desc_), oflags); 
+		topsf->fd_ = uinfile_open(filename, (mode_t)(0), &(topsf->format_desc_), oflags); 
 	}
 	E_DEBUG("");
 	
@@ -701,10 +701,15 @@ TOPSF * topsf_open(char * filename, int oflags, char * package_name)
 	topsf->prefix_=(char*)(NULL);
 	topsf->hl_node_names_ = cplob_open(1);
 	topsf->hl_linkto_names_ = cplob_open(1);
-	topsf->archive_names_ = cplob_open(1);
+	/* topsf->archive_names_ = cplob_open(1); */
+	topsf->archive_namesM = strar_open();
+
+	topsf->file_status_arrayM = strob_open(1);
+	topsf->header_namesM = strar_open();
+	strob_set_fill_char(topsf->file_status_arrayM, (int)'0'/* ascii zero, i.e. decimal 48 */);
 	cplob_additem(topsf->hl_node_names_, 0, NULL);
 	cplob_additem(topsf->hl_linkto_names_, 0, NULL);
-	cplob_additem(topsf->archive_names_, 0, NULL);
+	/* cplob_additem(topsf->archive_names_, 0, NULL); */
 	topsf->user_addr=NULL;
 	topsf->use_recursive_ = 0;
 	topsf->reverse_links_ = 0;
@@ -726,6 +731,9 @@ TOPSF * topsf_open(char * filename, int oflags, char * package_name)
 	topsf->ownerM = NULL;
 	topsf->groupM = NULL;
 	topsf->exclude_listM = NULL;
+	topsf->rpmtag_default_prefixM = NULL;
+	topsf->verboseM = 0;
+	topsf->usebuf1M = strob_open(40);
 	return topsf_i_package_open(topsf, oflags);
 }
 
@@ -769,6 +777,7 @@ TOPSF *
 topsf_i_package_open(TOPSF * topsf, int oflags) {
 	int rc, isSource;
 	STROB * tagval = strob_open(12);
+	char * uncompressor;
 	int tagret = -1;
 	int ret;
 
@@ -791,9 +800,17 @@ topsf_i_package_open(TOPSF * topsf, int oflags) {
 			if (tagret != 0) {
 				strob_strcpy(tagval, "gzip");
 			}
+			uncompressor = strdup(strob_str(tagval));
+
+			tagret = rpmpsf_get_rpmtagvalue(topsf->h_, RPMTAG_DEFAULTPREFIX, 0, (int*)(NULL), tagval);
+			if (tagret == 0) {
+				fprintf(stderr, "%s: Warning: RPM file uses deprecated RPMTAG_DEFAULTPREFIX(1056): %s\n",
+							swlib_utilname_get(), strob_str(tagval));
+				topsf->rpmtag_default_prefixM = strdup(strob_str(tagval));
+			}
 
 			if ((oflags & TOPSF_OPEN_NO_AUDIT) == 0) {
-				if (topsf_rpm_do_audit_hard_links(topsf, topsf->fd_, oflags, strob_str(tagval))) {
+				if (topsf_rpm_do_audit_hard_links(topsf, topsf->fd_, oflags, uncompressor)) {
 					E_DEBUG("ABNORMAL FUNCTION EXIT");
 					strob_close(tagval);
 					return NULL;
@@ -898,6 +915,7 @@ topsf_add_fl_entry(TOPSF * topsf, char * to_name, char * from_name, int source_c
 	* to_name is the name the original rpm archive.
 	*/
 	/* fprintf(stderr, "to_name=[%s], from_name=[%s]\n", to_name, from_name);  */
+	E_DEBUG3("BEGINNING: to_name=[%s] from_name=[%s]", to_name, from_name);
 	if (topsf->cwd_prefix_) { 
 		if (!strstr(from_name, topsf->cwd_prefix_)) {
 			E_DEBUG("exception");
@@ -920,6 +938,7 @@ topsf_add_fl_entry(TOPSF * topsf, char * to_name, char * from_name, int source_c
 			from_name++; */ /* move forward off the '/'*/
 		}
 	}
+	E_DEBUG3("ADDDING ENTRY: to_name=[%s] from_name=[%s]", to_name, from_name);
 	swacfl_add(topsf->swacfl_, to_name, from_name, source_code);
 	E_DEBUG("FUNCTION EXIT");
 }
@@ -1066,11 +1085,15 @@ topsf_rpm_audit_hard_links(TOPSF * topsf, int fd)
 		}
 		
 		/* fprintf(stderr, "ADDING FILENAME = [%s]\n", ahsStaticGetTarFilename(file_hdr));  */
+		/*
 		cplob_additem(topsf->archive_names_, 
 				cplob_get_nused(topsf->archive_names_)-1, 
 						swlib_strdup(ahsStaticGetTarFilename(file_hdr)));
 		cplob_additem(topsf->archive_names_, cplob_get_nused(topsf->archive_names_), NULL);
-		
+		*/
+
+		strar_add(topsf->archive_namesM, ahsStaticGetTarFilename(file_hdr));
+
 		/* FIXME check for eoa */
 		if ((file_hdr->c_mode & CP_IFMT) == CP_IFREG) {
 			if (taru_write_archive_member_data(topsf->taruM, file_hdr,
@@ -1164,7 +1187,7 @@ topsf_rpm_find_linkname(TOPSF * topsf, char * base_link, int fd, struct new_cpio
 		if (!strcmp(ahsStaticGetTarFilename(file_hdr1),"TRAILER!!!"))
 			break;
 	}
-	ahsStaticSetTarLinkname(base_file_hdr, lastmatch);
+	ahsStaticSetPaxLinkname(base_file_hdr, lastmatch);
 	ahsStaticDeleteFilehdr(file_hdr1);
 	E_DEBUG("FUNCTION EXIT");
 	if (uxfio_lseek(fd, oldoffset, SEEK_SET) != oldoffset) {
@@ -1174,6 +1197,141 @@ topsf_rpm_find_linkname(TOPSF * topsf, char * base_link, int fd, struct new_cpio
 	return 0;
 }
 
+int
+topsf_copypass_swacfl_write_missing_files(TOPSF * topsf, XFORMAT * xux, SWVARFS * swvarfs, int ofd)
+{
+	char * missing_array;
+	char * ch;
+	int c;
+	int headerindex;
+	int fnameindex;
+	int hret;
+	char * name;
+	STROB * fname;
+	STROB * strb;
+	STROB * linkname;
+	mode_t mode;
+	Header h;
+	int ret;
+	AHS * ahs;
+	time_t tm;
+	int nullfd;
+
+	tm = time(NULL);
+
+	h = topsf->h_;
+	fname = strob_open(32);
+	strb = strob_open(32);
+	linkname = strob_open(32);
+	missing_array = strob_str(topsf->file_status_arrayM);
+	ch = missing_array; /* Nul terminated */
+
+	E_DEBUG("START");
+	while(*ch) {
+		c = (int)(*ch);
+		headerindex = (int)(ch - missing_array);
+		if (c == TOPSF_FILE_STATUS_IN_HEADER && topsf->rpm_construct_missing_filesM == 0) {
+			/*
+			 * Do not construct it
+			 */
+			rpmpsf_get_rpm_filenames_tagvalue(h, headerindex, (int *)NULL, fname);
+			fprintf(stderr, "%s: RPM file entry missing from archive: %s\n",
+							swlib_utilname_get(), strob_str(fname));
+		} else if (c == TOPSF_FILE_STATUS_IN_HEADER && topsf->rpm_construct_missing_filesM) {
+			/*
+			 * Found missing file
+			 * Write out the file as zero length using the stats from the rpm Header
+			 */
+			E_DEBUG2("found missing at index=%d", headerindex);
+			rpmpsf_get_rpm_filenames_tagvalue(h, headerindex, (int *)NULL, fname);
+			E_DEBUG2("missing filename=%s", strob_str(fname));
+
+			ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMODES, headerindex, (int *) NULL, strb);
+			mode = (mode_t) swlib_atoi(strob_str(strb), NULL);
+			if (S_ISREG(mode) || S_ISDIR(mode) || S_ISLNK(mode)) {
+				ahs = xformat_ahs_object(xux);
+				ahs_init_header(ahs);
+				if ( S_ISLNK(mode) ) {
+					/*
+					 * Need to find the linksource name from the Header
+					 */
+					fnameindex = rpmpsf_get_index_by_name(topsf, strob_str(fname));
+					if (fnameindex >= 0) {
+						hret = rpmpsf_get_rpmtagvalue(h, RPMTAG_FILELINKTOS,
+									fnameindex,
+									(NULL), linkname);
+						if (hret) {
+							/*
+							 * Error
+							 */
+							ret = -1;
+							goto SKIPLINK;
+						}
+						xformat_set_linkname(xux, strob_str(linkname));
+						xformat_set_mode(xux, (mode_t)(C_ISLNK|0777));
+						if (topsf->verboseM > 1)
+							fprintf(stderr, "%s: setting perms 0777 for symlink in archive: %s\n",
+							swlib_utilname_get(), strob_str(fname));
+					} else {
+						;
+						/*
+						 * Error
+						 */
+						ret = -1;
+						goto SKIPLINK;
+					} 
+				} else {
+					xformat_set_mode(xux, mode);
+				}
+				swlib_squash_leading_slash(strob_str(fname));
+				xformat_set_name(xux, strob_str(fname));
+	
+				ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEUSERNAME, headerindex, (int *) NULL, strb);
+				xformat_set_username(xux, strob_str(strb));
+				xformat_set_uid(xux, (uid_t)99);
+				xformat_set_user_systempair(xux, strob_str(strb));
+
+				ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEGROUPNAME, headerindex, (int *) NULL, strb);
+				xformat_set_groupname (xux, strob_str(strb));
+				xformat_set_gid(xux, (gid_t)99);
+				xformat_set_group_systempair(xux, strob_str(strb));
+
+				xformat_set_mtime(xux, tm);
+				xformat_set_filesize(xux, 0);
+				nullfd = open("/dev/null", O_RDWR, 0);
+				ret = xformat_write_by_fd(xux, nullfd, ahs_vfile_hdr(ahs));
+				close(nullfd);
+SKIPLINK:
+				if (ret < 0) {
+					fprintf(stderr, "%s: error constructing missing file: %s\n",
+							swlib_utilname_get(), strob_str(fname));
+				} else {
+					if (topsf->verboseM > 1)
+						fprintf(stderr, "%s: file constructed for RPM Header entry with missing file: %s\n",
+							swlib_utilname_get(), strob_str(fname));
+				}
+				E_DEBUG2("writing missing file: xformat_write_by_fd returned [%d]", (int)ret);
+			} else {
+				fprintf(stderr, "%s: not creating missing file (filetype not supported): %s\n",
+							swlib_utilname_get(), strob_str(fname));
+			}
+		} else if (c == TOPSF_FILE_STATUS_IN_ARCHIVE) {
+			/* OK, good
+			 * Nothing to do
+			 */
+			; 
+		} else {
+			/* Bad,Never happens, should be hard error */
+			fprintf(stderr, "fatal error in topsf_copypass_swacfl_write_missing_files\n");
+			exit(2);
+		}
+		ch++;
+	}
+	strob_close(linkname);
+	strob_close(fname);
+	strob_close(strb);
+	return 0;
+}
 
 int
 topsf_copypass_swacfl_header_list(TOPSF * topsf, XFORMAT * xxformat, SWVARFS * swvarfs, int ofd)
@@ -1210,13 +1368,13 @@ topsf_copypass_swacfl_header_list(TOPSF * topsf, XFORMAT * xxformat, SWVARFS * s
 				file_hdr->c_uid=getuid();
 				file_hdr->c_gid=getgid();
 				file_hdr->c_nlink=1;
-				ahsStaticSetTarLinkname(file_hdr, NULL);
+				ahsStaticSetPaxLinkname(file_hdr, NULL);
 				file_hdr->c_mtime=topsf->mtimeM;
 				file_hdr->c_filesize=0;
 				file_hdr->c_namesize=strlen(en->from_name_) +1;
 				file_hdr->c_chksum=0;
 				ahsStaticSetTarFilename(file_hdr, en->from_name_);
-				ahsStaticSetTarLinkname(file_hdr, NULL);
+				ahsStaticSetPaxLinkname(file_hdr, NULL);
 
 				switch(en->source_code_){
 					case SWACFL_SRCCODE_RPMHEADER:
@@ -1280,18 +1438,38 @@ topsf_copypass_swacfl_archive_list(TOPSF * topsf, XFORMAT * xxformat, SWVARFS *
 	SWACFL *swacfl=topsf->swacfl_;
 	struct stat st;
 	int (*do_write_file)(TOPSF * topsf, int o_fd);
-	CPLOB * archive_names = topsf->archive_names_;
 	int archive_name_index = 0;
 	char * archive_name;
+	STROB * tmp;
 
-	while ((archive_name = cplob_val(archive_names, archive_name_index++))) {
-		en = swacfl_find_entry(swacfl, archive_name);
+	tmp = strob_open(100);
+
+	while ((archive_name = strar_get(topsf->archive_namesM, archive_name_index++))) {
+		E_DEBUG2("archive_name=[%s]", archive_name ? archive_name : "<NULL>");
+		if (topsf->rpmtag_default_prefixM) {
+			strob_strcpy(tmp, topsf->rpmtag_default_prefixM);
+			swlib_add_trailing_slash(tmp);
+			strob_strcat(tmp, archive_name);
+			E_DEBUG2("will FIND ENTY prefix: tmp=[%s]", strob_str(tmp));
+			en = swacfl_find_entry(swacfl, strob_str(tmp));
+		} else {
+			E_DEBUG2("will FIND ENTY no prefix: archive_name=[%s]", archive_name);
+			en = swacfl_find_entry(swacfl, archive_name);
+		}
 		if (!en) {
-			fprintf(stderr, "Internal fatal error, swacfl entry not found for [%s]\n", archive_name);
+			fprintf(stderr, "lxpsf: Internal fatal error, swacfl entry not found for [%s]\n", archive_name);
 			exit(1);
 		}
 		if (savep) free(savep);
-		savep = swlib_strdup(strob_str(en->archiveNameM));
+
+		if (topsf->rpmtag_default_prefixM) {
+			savep = swlib_strdup(archive_name);
+		} else {
+			savep = swlib_strdup(strob_str(en->archiveNameM));
+		}
+		E_DEBUG2("WILL OPEN: savep = [%s]", savep);
+		E_DEBUG2("en->from_name_ = [%s]", en->from_name_);
+
 		p = savep;
 		swlib_process_hex_escapes(p);
 		swlib_unexpand_escapes(NULL, p);
@@ -1310,17 +1488,33 @@ topsf_copypass_swacfl_archive_list(TOPSF * topsf, XFORMAT * xxformat, SWVARFS *
 				E_DEBUG("SWACFL_SRCCODE_ARCHIVE_STREAM #1");
 				swvarfs_u_fstat(swvarfs, u_fd, &st);	
 				E_DEBUG("SWACFL_SRCCODE_ARCHIVE_STREAM #2");
-				taru_statbuf2filehdr(file_hdr, &st,
-						(char*)NULL, p/*en->from_name_*/,
+
+
+				if (topsf->rpmtag_default_prefixM) {
+					taru_statbuf2filehdr(file_hdr, &st, (char*)NULL, en->from_name_,
 						swvarfs_u_get_linkname(swvarfs, u_fd));
+				} else {
+					taru_statbuf2filehdr(file_hdr, &st, (char*)NULL, p /*en->from_name_*/,
+						swvarfs_u_get_linkname(swvarfs, u_fd));
+				}
+
 				E_DEBUG("SWACFL_SRCCODE_ARCHIVE_STREAM #3");
 				file_hdr->c_uid=getuid();
 				file_hdr->c_gid=getgid();
 				xformat_write_by_fd(xxformat, u_fd, file_hdr);
 				E_DEBUG3("OK %s %s", p, en->from_name_);
 				ahsStaticSetTarFilename(file_hdr, NULL);
-				ahsStaticSetTarLinkname(file_hdr, NULL);
+				ahsStaticSetPaxLinkname(file_hdr, NULL);
 				swvarfs_u_close(swvarfs, u_fd);
+				if (topsf_check_header_list(topsf, topsf->header_namesM, archive_name)) {
+					/*
+					 * This is an error
+					 * Every file in the archive should be found in the Header,
+					 * The end result is the file_status_array will indicate the files
+					 * that are in the Header but not in the archive.
+					 */
+					fprintf(stderr, "%s: topsf_check_header_list() indicates not found: [%s]\n", swlib_utilname_get(), archive_name);
+				}
 				E_DEBUG("leaving SWACFL_SRCCODE_ARCHIVE_STREAM");
 				break;
 
@@ -1335,13 +1529,13 @@ topsf_copypass_swacfl_archive_list(TOPSF * topsf, XFORMAT * xxformat, SWVARFS *
 				file_hdr->c_uid=getuid();
 				file_hdr->c_gid=getgid();
 				file_hdr->c_nlink=1;
-				ahsStaticSetTarLinkname(file_hdr, NULL);
+				ahsStaticSetPaxLinkname(file_hdr, NULL);
 				file_hdr->c_mtime=topsf->mtimeM;
 				file_hdr->c_filesize=0;
 				file_hdr->c_namesize=strlen(en->from_name_) +1;
 				file_hdr->c_chksum=0;
 				ahsStaticSetTarFilename(file_hdr, en->from_name_);
-				ahsStaticSetTarLinkname(file_hdr, NULL);
+				ahsStaticSetPaxLinkname(file_hdr, NULL);
 
 				switch(en->source_code_){
 					case SWACFL_SRCCODE_RPMHEADER:
@@ -1383,6 +1577,9 @@ topsf_copypass_swacfl_archive_list(TOPSF * topsf, XFORMAT * xxformat, SWVARFS *
 				break;
 		}
 	}
+
+	E_DEBUG2("status_array [%s]", strob_str(topsf->file_status_arrayM));
+
 	if (savep) free(savep);
 	ahsStaticDeleteFilehdr(file_hdr);
 	E_DEBUG("FUNCTION EXIT");
@@ -1401,13 +1598,28 @@ topsf_copypass_swacfl_list(TOPSF * topsf, int ofd)
 	if (!swvarfs) {
 		return -1;
 	}
+	E_DEBUG("running topsf_copypass_swacfl_header_list");
 	ret = topsf_copypass_swacfl_header_list(topsf, xxformat, swvarfs, ofd);
 	if (ret != 0) {
 		fprintf(stderr, "topsf_copypass_swacfl_list: error writing header files\n");
 		return ret;
 	}
+	E_DEBUG("running topsf_copypass_swacfl_archive_list");
 	ret = topsf_copypass_swacfl_archive_list(topsf, xxformat, swvarfs, ofd);
-	
+
+	/*
+	 * Now write the files that are in the header but not in the cpio archive
+	 */
+
+	if (topsf->rpmtag_default_prefixM != NULL) {
+		/* with these rare packages that use this deprecated tag, do
+		 * not construct missing file
+		 */
+		;
+	} else {
+		topsf_copypass_swacfl_write_missing_files(topsf, xxformat, swvarfs, ofd);
+	}
+
 	swvarfs_close(swvarfs);
  	xformat_write_trailer(xxformat); 
 	xformat_close(xxformat);
@@ -1548,3 +1760,68 @@ topsf_h_write_to_buf(XFORMAT * xformat, char * name, STROB ** buf)
 	xformat_u_close_file(xformat, ufd);
 	return ret;
 }
+	
+int
+topsf_search_list(TOPSF * topsf, STRAR * list, char * archive_name)
+{
+	char *s1;
+	int ret;
+	int i = 0;
+
+	/* Find archive_name in list
+	 * and check the topsf->file_status_arrayM
+	 */
+
+	while ((s1=strar_get(list, i)) != NULL) {
+		E_DEBUG3("comparing [%s] [%s]", s1, archive_name);
+
+		if (
+			(!strcmp(archive_name, "/") && !strcmp(s1, "./")) ||
+			(!strcmp(archive_name, "./") && !strcmp(s1, "/"))
+		) {
+			E_DEBUG3("found special case [%s] [%s]", s1, archive_name);
+			return i;
+		} else {
+			ret = swlib_dir_compare(s1, archive_name, SWC_FC_NOAB);
+			if (ret == 0) {
+				/* Found */
+				return i;
+			}
+		}
+		i++;
+	}
+	return -1;
+}
+
+int
+topsf_check_header_list(TOPSF * topsf, STRAR * list, char * archive_name)
+{
+	char *s1;
+	int ret;
+	int i = 0;
+	
+
+	/* Find archive_name in list
+	 * and check the topsf->file_status_arrayM
+	 */
+
+	if (topsf->rpmtag_default_prefixM) {
+		/*
+		 * Must prepend the prefix to archive_name
+		 */
+		E_DEBUG2("archive name [%s]", archive_name);
+		strob_strcpy(topsf->usebuf1M, topsf->rpmtag_default_prefixM);
+		swlib_unix_dircat(topsf->usebuf1M, archive_name);
+		E_DEBUG2("HAS prefix, searching for [%s]", strob_str(topsf->usebuf1M));
+		ret = topsf_search_list(topsf, list, strob_str(topsf->usebuf1M));
+	} else {
+		E_DEBUG2("searching for [%s]", archive_name);
+		ret = topsf_search_list(topsf, list, archive_name);
+	}
+	if (ret >= 0) {
+		strob_chr_index(topsf->file_status_arrayM,  ret, TOPSF_FILE_STATUS_IN_ARCHIVE);
+		return 0;
+	} else {
+		return 1;
+	}
+}
