@@ -43,6 +43,12 @@
  * ensure all of data on socket comes through. f==read || f==vwrite
  */
 
+ssize_t
+timed_atomic_read5(int fd, void * buf, size_t n)
+{
+	return timed_atomicio(read, fd, buf, n, (int)5);
+}
+
 ssize_t
 timed_atomicio(ssize_t (*f) (int, void *, size_t),  int fd, void * buf, size_t n, int timeout)
 {
@@ -60,7 +66,7 @@ timed_atomicio(ssize_t (*f) (int, void *, size_t),  int fd, void * buf, size_t n
 	flags = fcntl(fd, F_GETFL, O_NONBLOCK);
 	ret = fcntl(fd, F_SETFL, O_NONBLOCK);
 	if (flags < 0 || ret < 0) {
-		fprintf(stderr, "timed_atomico(): fcntl: (flags=%d): %s\n", flags, strerror(errno));
+		fprintf(stderr, "%s: non-blocking I/O request ignored, fcntl() status=%d: %s\n", swlib_utilname_get(), flags, strerror(errno));
 		E_DEBUG("");
 		return atomicio(f, fd, buf, n);
 	}
@@ -79,7 +85,6 @@ timed_atomicio(ssize_t (*f) (int, void *, size_t),  int fd, void * buf, size_t n
 		switch (res) {
 		case -1:
 			if (errno == EAGAIN) {
-				/* usleep (10000); */
 				continue;
 			}
 			return -1;
@@ -92,8 +97,7 @@ timed_atomicio(ssize_t (*f) (int, void *, size_t),  int fd, void * buf, size_t n
 	}
 	fcntl(fd, F_SETFL, flags);
 	if ((int)(tm - tm0) >= timeout) {
-		fprintf(stderr, "timed_atomico(): time limit exceeded: %d bytes, %d expected\n", pos, n);
-		pos = -1;
+		fprintf(stderr, "%s: %d second I/O time limit exceeded: %d bytes transferred, %d expected\n", swlib_utilname_get(), (int)timeout, (int)pos, (int)n);
 	}
 	return (pos);
 }
