@@ -65,6 +65,7 @@ fprintf(file, "%s",
 "  -H, --format FORMAT   Output format  ustar, gnutar, newc, crc, odc\n"
 "  --verbose-level=LEVEL\n"
 "  -v, --verbose\n"
+"  -N, --null-fd   Set stdout to  a /dev/null fd (Useful for debugging)\n"
 "  -n, --sig-number=N  select Nth signature for verification; first is N=1,\n"
 "                      last is N=0.\n"
 "  -m, --numeric-owner\n"
@@ -77,6 +78,7 @@ fprintf(file, "%s",
 "                     Re-encodes the header with the swbis personality.\n"
 "  --audit  Pass the input thru to the output unchanged and audit.\n"
 "  -p, --pass-thru   Pass the input thru to the output unchanged.\n"
+"  --recompress   Applies to pass thru\n"
 "  -C, --catalog-sign-file  Write the catalog signature input file to stdout.\n"
 "  -S, --storage-digest-file  Write the storage digest input file to stdout.\n"
 "  -s, --adjunct-digest-file  Write the adjunct digest input file to stdout.\n"
@@ -171,7 +173,9 @@ main (int argc, char *argv[])
 	int iret;
 	int logger_fd;
 	int signed_bytes_fd;
-	int which_sig = 0; /* 0 means last */
+	int do_recompress = 0;
+	int which_sig = -1; /* 0 means last, -1 means all, 1 means first */
+	int stdoutXfileno;
 	uintmax_t statbytes;
 	char * gpg_prog = NULL;
 	char * filearg;
@@ -180,14 +184,15 @@ main (int argc, char *argv[])
 	char * sigfilename = NULL;
 	char * which_sig_arg;
 
+	stdoutXfileno = STDOUT_FILENO;
 	flags = UINFILE_DETECT_FORCEUXFIOFD | 
 			UINFILE_DETECT_IEEE | 
 				UINFILE_UXFIO_BUFTYPE_MEM;
 	gpg_prog = strdup(SWGPG_GPG_BIN);
-	signed_bytes_fd = STDOUT_FILENO;
+	signed_bytes_fd = stdoutXfileno;
 	logger_fd = STDERR_FILENO;
 	verboseG = uverbose;
-	which_sig_arg = strdup("0");
+	which_sig_arg = strdup("-1");
 	swlib_utilname_set("arf2arf");
 
 	E_DEBUG("");
@@ -209,6 +214,7 @@ main (int argc, char *argv[])
                {"debug-mode", 0, 0, 'D'},
                {"catalog-sign-file", 0, 0, 'C'},
                {"storage-sign-file", 0, 0, 'S'},
+               {"null-ofd", 0, 0, 'N'},
                {"adjunct-storage-sign-file", 0, 0, 's'},
                {"show-auth-files", 0, 0, 'd'},
                {"sig-number", 1, 0, 'n'},
@@ -225,10 +231,11 @@ main (int argc, char *argv[])
                {"util-name", 1, 0, 165},
                {"logger-fd", 1, 0, 166},
                {"signed-bytes-fd", 1, 0, 167},
+               {"recompress", 0, 0, 168},
                {0, 0, 0, 0}
              };
 
-             c = ugetopt_long (argc, argv, "n:pdsSCxDH:G:v",
+             c = ugetopt_long (argc, argv, "n:NpdsSCxDH:G:v",
                         long_options, &option_index);
              if (c == -1) break;
 
@@ -250,6 +257,13 @@ main (int argc, char *argv[])
 		case 'D':
 			debugmode = 1;
 			break;
+		case 'N':
+			stdoutXfileno =  open("/dev/null", O_RDWR, 0);
+			if (stdoutXfileno < 0) {
+				fprintf(stderr, "%s : %s\n", argv[0], strerror(errno)); 
+				exit(1);
+			}
+			break;
 		case 'n':
 			which_sig = swlib_atoi(optarg, NULL);
 			which_sig_arg = strdup(optarg);
@@ -331,6 +345,9 @@ main (int argc, char *argv[])
 		case 167:
 			set_if_fd(optarg, &signed_bytes_fd, "signed-bytes-fd");
 			break;
+		case 168:
+			do_recompress = 1;
+			break;
 		default:
 			usage(stderr, argv[0]);
 			exit (2);
@@ -369,19 +386,26 @@ main (int argc, char *argv[])
 	}
 	
 	if (do_checksig) {
+		E_DEBUG2("which_sig_arg=[%s]", which_sig_arg);
 		ret = swgpg_run_checksig2(sigfilename,
 				SWBISLIBEXECDIR "/swbis/arf2arf", 
 					filearg, gpg_prog, uverbose, which_sig_arg);
+		E_DEBUG2("swgpg_run_checksig2 ret=[%d]", ret);
 		if (uverbose>5) fprintf(stderr, 
 				"%s: do_checksig returned %d\n", swlib_utilname_get(), ret);
 		if (ret < 0) ret = 1;
+		E_DEBUG2("exiting ret=[%d]", ret);
 		exit(ret);
 	}
 
 	E_DEBUG("");
-	xformat = xformat_open(STDIN_FILENO, STDOUT_FILENO, format);
+	xformat = xformat_open(STDIN_FILENO, stdoutXfileno, format);
 	if (!xformat) exit(1);
 
+	if (do_recompress) {
+		flags = flags | UINFILE_DETECT_RECOMPRESS;
+	}
+
 	if (xformat_open_archive_by_fd(xformat, fd, flags, 0)) {
 		if (get_sign_if) {
 			int sigfd = open(sigfilename, 
@@ -394,7 +418,7 @@ main (int argc, char *argv[])
 				close(sigfd);
 			}
 		}
-		close(STDOUT_FILENO);
+		close(stdoutXfileno);
 		exit(1);
 	}
 
@@ -422,11 +446,11 @@ main (int argc, char *argv[])
 
 		if (do_decode_pass_thru) {
 			/*
-			* decodes and re-encodes the archive therefore 
-			* possibly changing it.
+			* decodes tar headers and and re-encodes the tar headers
+			* archive therefore possibly altering the headers.
 			*/
-			ret = swlib_write_signing_files(xformat, 
-						STDOUT_FILENO, 1, 0);
+			ret = swlib_write_signing_files(xformat, stdoutXfileno,
+				1 /* 0=catalog section 1=storage section */, 0);
 		} else {
 			/*
 			* Decodes, but writes output that is identical
@@ -434,7 +458,7 @@ main (int argc, char *argv[])
 			*/
 			ret = taruib_write_storage_stream(
 					(void *)xformat,
-					STDOUT_FILENO,
+					stdoutXfileno,
 					1 		/*version*/, 
 					-1		/*adjunct_ofd*/ , 
 					verbose_stderr 	/*verbose*/, 
@@ -446,13 +470,14 @@ main (int argc, char *argv[])
 		xformat_set_tarheader_flag(xformat,
 					TARU_TAR_FRAGILE_FORMAT, 1 /*on*/ );
 		E_DEBUG("");
+		E_DEBUG2("which_sig=[%d]",  which_sig);
 		ret = taruib_write_signedfile_if(
 				(void*)xformat, 
 				signed_bytes_fd, 
 				sigfilename, 
 				uverbose,
 				which_sig /*last signature*/, logger_fd); 
-		E_DEBUG("");
+		E_DEBUG2("taruib_write_signedfile_if: ret=%d", ret);
 		if (uverbose >= 5) {
 			fprintf(stderr,
 				"%s: taruib_write_signedfile_if returned %d\n",
@@ -462,7 +487,7 @@ main (int argc, char *argv[])
 		enforce_tar_format(detected_format);
 		if (do_decode_pass_thru) {
 			swlib_write_signing_files(xformat,
-					STDOUT_FILENO, 1, 1);
+					stdoutXfileno, 1, 1);
 		} else {
 			int nullfd;
 			nullfd = open("/dev/null", O_RDWR, 0);
@@ -474,7 +499,7 @@ main (int argc, char *argv[])
 					(void*)xformat, 
 					nullfd, 
 					1 /* version */, 
-					STDOUT_FILENO, 
+					stdoutXfileno, 
 					verbose_stderr, 
 					digest_type);
 		}
@@ -483,13 +508,13 @@ main (int argc, char *argv[])
 		if (do_decode_pass_thru) {
 			ret = swlib_write_signing_files(
 				xformat, 
-				STDOUT_FILENO, 
+				stdoutXfileno, 
 				0, 
 				0);
 		} else {
 			ret = taruib_write_catalog_stream(
 				(void*)xformat, 
-				STDOUT_FILENO, 
+				stdoutXfileno, 
 				1 /* version */, 
 				verbose_stderr);
 		}
@@ -498,24 +523,72 @@ main (int argc, char *argv[])
 				TARU_TAR_FRAGILE_FORMAT, 1 /*on*/ );
 		ret = taruib_write_storage_stream(
 			xformat, 
-			STDOUT_FILENO, 
+			stdoutXfileno, 
 			1 /*version*/, 
 			STDERR_FILENO, 
 			0 /*verbose*/, 
 			digest_type);	
 
 	} else if (pass_thru_mode) {
-		ret = taruib_write_pass_files(
-			(void*)xformat, 
-			STDOUT_FILENO, 
-			-1);
+		/* uncompress write-thru and re-compress per options */
+		SHCMD ** cmd_vec;
+		SHCMD * cmd;
+		int ipipe[2];
+		pid_t childi;
+
+		if (do_recompress) {
+			E_DEBUG("do_recompress");
+			cmd_vec = uinfile_get_recompress_vector(
+					swvarfs_get_uinformat(
+						xformat_get_swvarfs(xformat)
+					)
+				);
+		} else {
+			cmd_vec = NULL;
+		}
+
+		if (cmd_vec) {
+			/* restore the compression */
+			E_DEBUG("do_recompress: have cmd_vec");
+			pipe(ipipe);
+			childi = swfork((sigset_t*)(NULL));
+			if (childi == 0) {
+				int ret;
+				swgp_signal(SIGPIPE, SIG_DFL);
+				swgp_signal(SIGINT, SIG_DFL);
+				swgp_signal(SIGTERM, SIG_DFL);
+				swgp_signal(SIGUSR1, SIG_DFL);
+				swgp_signal(SIGUSR2, SIG_DFL);
+				close(ipipe[0]);
+				ret = taruib_write_pass_files((void*)xformat, ipipe[1], -1);
+				if (ret < 0)
+					ret = 1;
+				else
+					ret = 0;
+				_exit(ret);
+			}
+			E_DEBUG("");
+			if (childi < 0) {
+				return -1;
+			}
+			close(ipipe[1]);
+			shcmd_set_srcfd(cmd_vec[0], ipipe[0]);
+			cmd = shcmd_get_last_command(cmd_vec);
+			shcmd_set_dstfd(cmd, stdoutXfileno);
+			shcmd_cmdvec_exec(cmd_vec);
+			ret = shcmd_cmdvec_wait2(cmd_vec);
+			if (ret != 0) ret = -1;
+		} else {
+			ret = taruib_write_pass_files((void*)xformat, stdoutXfileno, -1); 
+		}
+
 	} else if (do_audit) {
 		/*
 		* Test use of the swlib_arfcopy() and swi_<*> routines.
 		*/
 		ret = swlib_audit_distribution(xformat, 
 					do_decode_pass_thru, 
-					STDOUT_FILENO, 
+					stdoutXfileno, 
 					&statbytes, 
 					(int*)(NULL),
 					(void (*)(int))(NULL));
@@ -530,7 +603,7 @@ main (int argc, char *argv[])
 				break;
 			}
 			xformat_write_header(xformat);
-			xformat_copy_pass(xformat, STDOUT_FILENO, ifd);
+			xformat_copy_pass(xformat, stdoutXfileno, ifd);
 		}
 		
 		if (ret >= 0) {
@@ -541,7 +614,6 @@ main (int argc, char *argv[])
 		}
 	}
 
-
 	iret = xformat_close(xformat);
 	if (fd != STDIN_FILENO) close(fd);
 
@@ -554,5 +626,6 @@ main (int argc, char *argv[])
 
 	/* close(STDERR_FILENO); */
 	if (ret < 0) ret = 1;
+	E_DEBUG2("exiting with [%d]", ret);
 	exit(ret);
 }
