@@ -108,7 +108,8 @@ void  usage (char * progname, FILE * fp) {
     fprintf (fp, "   --owner=NAME  package owner\n");
     fprintf (fp, "   --group=NAME  package group\n");
     fprintf (fp, "   --exclude=NAME  add exclude directive to the PSF\n");
-    fprintf (fp, "   --exclude-system-dirs  exclude all system directories, such as /usr, /usr/bin,...\n");
+    fprintf (fp, "   --exclude-system-dirs  exclude all system directories listed in manual page\n"
+	         "         hier(7) (conforming to FHS 2.2)\n");
     fprintf (fp, "   -d, --debug-level=TYPE    always use 'link'\n");
     fprintf (fp, "   -D checkdigest  checkdigest script, applies to plain tarball translation.\n");
     fprintf (fp, "   -x, --use-recursive-fileset Use \"file *\" instead of individual file definitions.\n");
@@ -144,44 +145,129 @@ static
 void
 add_system_dirs(STRAR * exclude_list)
 {
-
-	strar_add(exclude_list, "/");
-	strar_add(exclude_list, "/tmp");
-	strar_add(exclude_list, "/var");
-	strar_add(exclude_list, "/var/spool");
-	strar_add(exclude_list, "/var/log");
-	strar_add(exclude_list, "/etc");
-	strar_add(exclude_list, "/etc/init.d");
-	strar_add(exclude_list, "/usr");
-	strar_add(exclude_list, "/bin");
-	strar_add(exclude_list, "/sbin");
-	strar_add(exclude_list, "/opt");
-	strar_add(exclude_list, "/usr/sbin");
-	strar_add(exclude_list, "/usr/bin");
-	strar_add(exclude_list, "/usr/man");
-	strar_add(exclude_list, "/usr/lib");
-	strar_add(exclude_list, "/usr/info");
-	strar_add(exclude_list, "/usr/doc");
-	strar_add(exclude_list, "/usr/X11R6");
-	strar_add(exclude_list, "/usr/man/man1");
-	strar_add(exclude_list, "/usr/man/man2");
-	strar_add(exclude_list, "/usr/man/man3");
-	strar_add(exclude_list, "/usr/man/man4");
-	strar_add(exclude_list, "/usr/man/man5");
-	strar_add(exclude_list, "/usr/man/man6");
-	strar_add(exclude_list, "/usr/man/man7");
-	strar_add(exclude_list, "/usr/man/man8");
-	strar_add(exclude_list, "/usr/share");
-	strar_add(exclude_list, "/usr/share/man/man1");
-	strar_add(exclude_list, "/usr/share/man/man2");
-	strar_add(exclude_list, "/usr/share/man/man3");
-	strar_add(exclude_list, "/usr/share/man/man4");
-	strar_add(exclude_list, "/usr/share/man/man5");
-	strar_add(exclude_list, "/usr/share/man/man6");
-	strar_add(exclude_list, "/usr/share/man/man7");
-	strar_add(exclude_list, "/usr/share/man/man8");
-	strar_add(exclude_list, "/lib");
-	strar_add(exclude_list, "/libexec");
+	strar_add(exclude_list, ".//");
+	strar_add(exclude_list, "/bin//");
+	strar_add(exclude_list, "/boot//");
+	strar_add(exclude_list, "/dev//");
+	strar_add(exclude_list, "/etc//");
+	strar_add(exclude_list, "/etc/opt//");
+	strar_add(exclude_list, "/etc/sgml//");
+	strar_add(exclude_list, "/etc/skel//");
+	strar_add(exclude_list, "/etc/X11//");
+	strar_add(exclude_list, "/home//");
+	strar_add(exclude_list, "/lib//");
+	strar_add(exclude_list, "/media//");
+	strar_add(exclude_list, "/mnt//");
+	strar_add(exclude_list, "/opt//");
+	strar_add(exclude_list, "/proc//");
+	strar_add(exclude_list, "/root//");
+	strar_add(exclude_list, "/sbin//");
+	strar_add(exclude_list, "/srv//");
+	strar_add(exclude_list, "/tmp//");
+	strar_add(exclude_list, "/usr//");
+	strar_add(exclude_list, "/usr/X11R6//");
+	strar_add(exclude_list, "/usr/X11R6/bin//");
+	strar_add(exclude_list, "/usr/X11R6/lib//");
+	strar_add(exclude_list, "/usr/X11R6/lib/X11//");
+	strar_add(exclude_list, "/usr/X11R6/include/X11//");
+	strar_add(exclude_list, "/usr/bin//");
+	strar_add(exclude_list, "/usr/bin/X11//");
+	strar_add(exclude_list, "/usr/dict//");
+	strar_add(exclude_list, "/usr/doc//");
+	strar_add(exclude_list, "/usr/etc//");
+	strar_add(exclude_list, "/usr/games//");
+	strar_add(exclude_list, "/usr/include//");
+	strar_add(exclude_list, "/usr/include/X11//");
+	strar_add(exclude_list, "/usr/include/asm//");
+	strar_add(exclude_list, "/usr/include/linux//");
+	strar_add(exclude_list, "/usr/include/g++//");
+	strar_add(exclude_list, "/usr/lib//");
+	strar_add(exclude_list, "/usr/lib/X11//");
+	strar_add(exclude_list, "/usr/lib/gcc-lib//");
+	strar_add(exclude_list, "/usr/lib/groff//");
+	strar_add(exclude_list, "/usr/lib/uucp//");
+	strar_add(exclude_list, "/usr/local//");
+	strar_add(exclude_list, "/usr/local/bin//");
+	strar_add(exclude_list, "/usr/local/doc//");
+	strar_add(exclude_list, "/usr/local/etc//");
+	strar_add(exclude_list, "/usr/local/games//");
+	strar_add(exclude_list, "/usr/local/lib//");
+	strar_add(exclude_list, "/usr/local/include//");
+	strar_add(exclude_list, "/usr/local/info//");
+	strar_add(exclude_list, "/usr/local/man//");
+	strar_add(exclude_list, "/usr/local/sbin//");
+	strar_add(exclude_list, "/usr/local/share//");
+	strar_add(exclude_list, "/usr/local/src//");
+	strar_add(exclude_list, "/usr/man//");
+	strar_add(exclude_list, "/usr/sbin//");
+	strar_add(exclude_list, "/usr/share//");
+	strar_add(exclude_list, "/usr/share/dict//");
+	strar_add(exclude_list, "/usr/share/doc//");
+	strar_add(exclude_list, "/usr/share/games//");
+	strar_add(exclude_list, "/usr/share/info//");
+	strar_add(exclude_list, "/usr/share/locale//");
+	strar_add(exclude_list, "/usr/share/man//");
+	strar_add(exclude_list, "/usr/share/man/man1//");
+	strar_add(exclude_list, "/usr/share/man/man2//");
+	strar_add(exclude_list, "/usr/share/man/man3//");
+	strar_add(exclude_list, "/usr/share/man/man4//");
+	strar_add(exclude_list, "/usr/share/man/man5//");
+	strar_add(exclude_list, "/usr/share/man/man6//");
+	strar_add(exclude_list, "/usr/share/man/man7//");
+	strar_add(exclude_list, "/usr/share/man/man8//");
+	strar_add(exclude_list, "/usr/share/man/man9//");
+	strar_add(exclude_list, "/usr/share/misc//");
+	strar_add(exclude_list, "/usr/share/nls//");
+	strar_add(exclude_list, "/usr/share/sgml//");
+	strar_add(exclude_list, "/usr/share/terminfo//");
+	strar_add(exclude_list, "/usr/share/tmac//");
+	strar_add(exclude_list, "/usr/share/zoneinfo//");
+	strar_add(exclude_list, "/usr/src//");
+	strar_add(exclude_list, "/usr/src/linux//");
+	strar_add(exclude_list, "/usr/tmp//");
+	strar_add(exclude_list, "/var//");
+	strar_add(exclude_list, "/var/adm//");
+	strar_add(exclude_list, "/var/backups//");
+	strar_add(exclude_list, "/var/cache/man/cat1//");
+	strar_add(exclude_list, "/var/cache/man/cat2//");
+	strar_add(exclude_list, "/var/cache/man/cat3//");
+	strar_add(exclude_list, "/var/cache/man/cat4//");
+	strar_add(exclude_list, "/var/cache/man/cat5//");
+	strar_add(exclude_list, "/var/cache/man/cat6//");
+	strar_add(exclude_list, "/var/cache/man/cat7//");
+	strar_add(exclude_list, "/var/cache/man/cat8//");
+	strar_add(exclude_list, "/var/cache/man/cat9//");
+	strar_add(exclude_list, "/var/catman/cat1//");
+	strar_add(exclude_list, "/var/catman/cat2//");
+	strar_add(exclude_list, "/var/catman/cat3//");
+	strar_add(exclude_list, "/var/catman/cat4//");
+	strar_add(exclude_list, "/var/catman/cat5//");
+	strar_add(exclude_list, "/var/catman/cat6//");
+	strar_add(exclude_list, "/var/catman/cat7//");
+	strar_add(exclude_list, "/var/catman/cat8//");
+	strar_add(exclude_list, "/var/catman/cat9//");
+	strar_add(exclude_list, "/var/cron//");
+	strar_add(exclude_list, "/var/lib//");
+	strar_add(exclude_list, "/var/local//");
+	strar_add(exclude_list, "/var/lock//");
+	strar_add(exclude_list, "/var/log//");
+	strar_add(exclude_list, "/var/opt//");
+	strar_add(exclude_list, "/var/mail//");
+	strar_add(exclude_list, "/var/msgs//");
+	strar_add(exclude_list, "/var/preserve//");
+	strar_add(exclude_list, "/var/run//");
+	strar_add(exclude_list, "/var/spool//");
+	strar_add(exclude_list, "/var/spool/at//");
+	strar_add(exclude_list, "/var/spool/cron//");
+	strar_add(exclude_list, "/var/spool/lpd//");
+	strar_add(exclude_list, "/var/spool/mail//");
+	strar_add(exclude_list, "/var/spool/mqueue//");
+	strar_add(exclude_list, "/var/spool/news//");
+	strar_add(exclude_list, "/var/spool/rwho//");
+	strar_add(exclude_list, "/var/spool/smail//");
+	strar_add(exclude_list, "/var/spool/uucp//");
+	strar_add(exclude_list, "/var/tmp//");
+	strar_add(exclude_list, "/var/yp//");
 }
 
 static
