@@ -19,7 +19,6 @@
 #define TARU_AR_HEADER_SIZE  60  /* GNU ar format */
 #define TARU_AR_SIZE_OFFSET  48  /* GNU ar format */
 
-#define SNAME_LEN            32
 
 /*
 	tar Header Block byte offsets
@@ -68,8 +67,9 @@
 #define GNUTYPE_LONGNAME 	'L'
 #define GNUTYPE_LONGLINK	'K'
 
-#define PREFIX_FIELD_SIZE 155
-#define NAME_FIELD_SIZE   100
+#define PREFIX_FIELD_SIZE 155    /* Tar Header field size, do not change */
+#define NAME_FIELD_SIZE   100    /* Tar Header field size, do not change */
+#define SNAME_LEN         32     /* Tar Header field size, do not change */
 
 #if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__ || defined __EMX__ || defined __DJGPP__ 
   /* Win32, Cygwin, OS/2, DOS */
@@ -107,7 +107,7 @@ typedef struct {
 } TARU;
 
 
-#define TARU_SYSDBNAME_LEN        40
+#define TARU_SYSDBNAME_LEN        120
 
 #define TARU_FORMAT_TAR 0
 #define TARU_FORMAT_CPIO 1
@@ -168,6 +168,10 @@ typedef struct {
 #define TARU_TAR_NAMESIZE_99		(1 << 11) /* Use 99 char name size split like oldgnu format */
 #define TARU_TAR_PAXEXTHDR		(1 << 12) /* Use Pax Extended Headers where needed */
 #define TARU_TAR_PAXEXTHDR_MD		(1 << 13) /* Mandatory Pax Extended Headers */
+#define TARU_TAR_ACLEXTHDR		(1 << 14) /* NOT Used in 1.13.1 */
+#define TARU_TAR_SELINUXEXTHDR		(1 << 15) /* NOT Used in 1.13.1 */
+#define TARU_TAR_NO_OVERFLOW		(1 << 16) /* Do not allow any fields to overflow */
+
 
 #define TARU_PV_0	0  /* preview level, no preview */
 #define TARU_PV_1	1  /* preview level, print filename */
@@ -481,7 +485,10 @@ void taru_exatt_delete(EXATT * p);
 void taru_exattlist_delete_all(struct new_cpio_header * file_hdr);
 EXATT * taru_exattlist_get_free(struct new_cpio_header * file_hdr);
 void taru_exattshow_debug(struct new_cpio_header * file_hdr);
-int taru_fill_exthdr_needs_mask(struct new_cpio_header * file_hdr, int tarheaderflags);
-int taru_ustar_field_size_check(struct new_cpio_header * file_hdr);
+/* int taru_ustar_field_size_check(struct new_cpio_header * file_hdr); */
+
+int taru_fill_exthdr_needs_mask(struct new_cpio_header * file_hdr, int tarheaderflags,
+		int is_pax_header_allowed, int be_verbose);
+
 
 #endif
