@@ -24,7 +24,7 @@ taru_format_translate (int ifd, int ofd, enum archive_format output_format ) {
 
    if (parent == 0) { /* child */
         close (fpipe[0]); 
-	_exit (taru_process_copy_in (ifd, fpipe[1])) ;
+	_exit (taru_process_copy_in (NULL, ifd, fpipe[1])) ;
    } else if (parent > 0) {
         close (fpipe[1]); 
         ret = taru_process_copy_out (taru, fpipe [0] , ofd, defer, NULL, output_format, -1, -1, (intmax_t*)NULL, NULL); 
