@@ -915,12 +915,15 @@ xformat_write_file_by_fd (XFORMAT * xux,
 					(int(*)(int))fout,
 					xux->output_format_codeM, -1, NULL);
 			if (ret1 < 0) {
-				fprintf(stderr, "taru_write_archive_member_data failed unexpectedly\n");
+				fprintf(stderr, "%s: error writing file member data\n",
+					swlib_utilname_get());
 				return -1;
 			}
 			ret += ret1;
 		} else {
-			fprintf(stderr, "taru_write_archive_member_header failed return code=%s\n", swlib_imaxtostr(ret, NULL));
+			fprintf(stderr, "%s: tar header write failed,  return code=%s\n",
+				swlib_utilname_get(),
+					swlib_imaxtostr(ret, NULL));
 			return -1;
 		}
 	} else {
