@@ -3,6 +3,8 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include "swparser_global.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 #define LINELEN 900
 
